@@ -15,9 +15,9 @@ NAME = __name__.split('.')[-1] # package name (e.g. 'foo' or 'foo_bar')
                                # please use a all-lowercase valid python
                                # package name
 
-VERSION = '1.4.57' # version of the packaged files, please use the upstream
+VERSION = '1.6.50' # version of the packaged files, please use the upstream
                   # version number
-BUILD = '0' # our package build number, so we can release new builds
+BUILD = '2' # our package build number, so we can release new builds
              # with fixes for xstatic stuff.
 PACKAGE_VERSION = VERSION + '.' + BUILD # version used for PyPi
 
@@ -28,14 +28,14 @@ CLASSIFIERS = []
 KEYWORDS = 'material design icons webfont mdi xstatic'
 
 # XStatic-* package maintainer:
-MAINTAINER = 'Diana Whitten'
-MAINTAINER_EMAIL = 'hurgleburgler@gmail.com'
+MAINTAINER = 'Rob Cresswell'
+MAINTAINER_EMAIL = 'robert.cresswell@outlook.com'
 
 # this refers to the project homepage of the stuff we packaged:
 HOMEPAGE = 'http://materialdesignicons.com'
 
 # this refers to all files:
-LICENSE = '(same as %s)' % DISPLAY_NAME
+LICENSE = 'SIL OFL 1.1'
 
 from os.path import join, dirname
 BASE_DIR = join(dirname(__file__), 'data')
